import Async, { CustomSignalClass, Signal } from "typescene-async";
import Block from "./Block";
import Component from "../Component";
import { ComponentFactory, ValueOrObservable } from "../ComponentFactory";
import { ActionHandler } from "../DOMEvents";
/** Represents a list of blocks */
export declare class List<BlockT extends Block> extends Block {
    /** Create a list component with given block items, if any */
    constructor(items?: BlockT[] | Async.ObservableArray<BlockT>);
    /** Initialize a list factory with given values */
    static with<BlockT extends Block>(values: List.Initializer<BlockT>): ComponentFactory<List<BlockT>>;
    /** Initialize a list factory with given items */
    static withItems<BlockT extends Block>(items: ComponentFactory.SpecList): ComponentFactory<List<BlockT>>;
    /** Class decorator that uses given initializer specification to initialize every component instance asynchronously (after running the component constructor) */
    static initializeWith: ComponentFactory.Decorator<List.Initializer<Block>, List<Block>>;
    /** Class decorator that uses given initializer specification to initialize every component instance asynchronously (after running the component constructor) */
    static initializeWithItems: ComponentFactory.Decorator<ComponentFactory.SpecList, List<Block>>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: List.Initializer<BlockT>) => this;
    /** List content (observed) */
    items: (BlockT | null)[];
    /** Set to a CSS color to insert a line between each element (observed) */
    dividerColor: string | undefined;
    /** Divider thickness (CSS value, default 1px, observed) */
    dividerThickness: string;
    /** Vertical whitespace around divider (CSS value, default 0, observed) */
    dividerMargin: string;
    /** Horizontal inset on left side of divider (CSS value, observed) */
    dividerInsetLeft: string | undefined;
    /** Horizontal inset on right side of divider (CSS value, observed) */
    dividerInsetRight: string | undefined;
    /** Set to true to enable element selection using click and up/down arrow keys (observed) */
    allowSelection: boolean;
    /** Currently selected item (Block), if any (observed) */
    selectedItem: BlockT | null;
    /** Currently selected item index (base 0) or -1 if no selection (observed/able) */
    selectedIndex: number;
    /** Set to a string value to have getFormValues add an ObservableArray with form values of list items */
    name: string;
    /** Returns an array of directly contained UI components (observable) */
    getChildren(): Component[];
    /** Returns an object containing all current values of input elements (observable) */
    getFormValues(result?: {}): {};
    /** Sets all input values by element name (will not trigger observable) */
    setFormValues(values: any): void;
    /** Signal emitted when the list selection changes */
    readonly SelectionChange: CustomSignalClass<BlockT | null, Signal<BlockT | null>>;
    private _clickConnections;
    private _dividers;
}
export declare namespace List {
    /** Initializer for .with({ ... }) */
    interface Initializer<BlockT extends Block> extends Block.Initializer {
        /** Property initializer: property name or list of items */
        items: string | ComponentFactory.SpecList;
        /** Property initializer */
        dividerColor?: ValueOrObservable<string | undefined>;
        /** Property initializer */
        dividerThickness?: ValueOrObservable<string | undefined>;
        /** Property initializer */
        dividerMargin?: ValueOrObservable<string | undefined>;
        /** Property initializer */
        dividerInsetLeft?: ValueOrObservable<string | undefined>;
        /** Property initializer */
        dividerInsetRight?: ValueOrObservable<string | undefined>;
        /** Property initializer */
        allowSelection?: ValueOrObservable<boolean>;
        /** Property initializer */
        selectedItem?: ValueOrObservable<BlockT>;
        /** Property initializer */
        selectedIndex?: ValueOrObservable<number>;
        /** Property initializer */
        name?: string;
        /** Signal initializer: method name or handler */
        SelectionChange?: string | ActionHandler<BlockT, any>;
    }
}
export default List;
