import { CustomSignalClass, Signal } from "typescene-async";
import Activity from "../../Activity";
import { ActivityResourcePath } from "../../ActivityPath";
import { Container } from "../";
import Block from "./Block";
import Component from "../Component";
import { ComponentFactory, ValueOrObservable } from "../ComponentFactory";
import TextLabelFactory from "../TextLabelFactory";
import { ActionHandler } from "../DOMEvents";
/** Represents a row of tabs or pills */
export declare class NavList extends Block {
    /** Create a navigation list component */
    constructor(navItems?: NavList.NavItem[], selectedIndex?: number, selectedKey?: string);
    /** Initialize a nav list factory with given values */
    static with: (values: NavList.Initializer) => ComponentFactory<NavList>;
    /** Initialize a nav list factory with given items */
    static withItems(navItems: NavList.NavItem[]): ComponentFactory<NavList>;
    /** Class decorator that uses given initializer specification to initialize every component instance asynchronously (after running the component constructor) */
    static initializeWith: ComponentFactory.Decorator<NavList.Initializer, NavList>;
    /** Class decorator that uses given initializer specification to initialize every component instance asynchronously (after running the component constructor) */
    static initializeWithItems: ComponentFactory.Decorator<NavList.NavItem[], NavList>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: NavList.Initializer) => this;
    /** Nav labels, icons, and badges (observed) */
    navItems: NavList.NavItem[];
    /** Index of selected item (base 0), or -1 if no selection (observed/able) */
    selectedIndex: number;
    /** Key of selected item (observed/able) */
    selectedKey: string | undefined;
    /** Type of nav: tabs or pills, inline or stacked; default tabs (observed) */
    type: NavList.Type;
    /** Set to true to fill all horizontal space */
    justified: boolean;
    /** Base activity class, reverted to (using application's .dropActivity) before starting activity using href on activated nav item */
    BaseActivityClass: typeof Activity | undefined;
    /** True if current/base activity should be pushed, not replaced, when clicking nav item with href or activity property (default false) */
    activityPushMode: boolean;
    /** Select given nav item by index or key, and start associated activity if any; returns this */
    activate(selection: number | string): this;
    /** Returns an array of directly contained UI components (observable) */
    getChildren(): Component[];
    /** Signal emitted when the selected nav item changes */
    readonly NavChange: CustomSignalClass<number, Signal<number>>;
    private _ul;
    private _li;
    private _containerBlock;
}
export declare namespace NavList {
    /** Represents an item in a navigation list (tab or pill) */
    interface NavItem {
        /** Text label */
        label?: string | TextLabelFactory;
        /** Icon (see Label) */
        icon?: string;
        /** Space reserved for icon (see Label) */
        iconGutter?: number;
        /** Badge text */
        badge?: string;
        /** Key (string ID) of the item, used with selectedKey */
        key?: string;
        /** Container to be displayed below tabs/pills when this item is selected */
        container?: Container;
        /** Path to activity/URL that is started when this item is selected; also used to activate nav item based on current location */
        href?: ActivityResourcePath | string;
        /** Activity that is started when this item is selected; also used to activate nav item based on current activity */
        activity?: Activity | typeof Activity;
    }
}
export declare namespace NavList {
    /** NavList display type */
    enum Type {
        /** Display as a row of tabs */
        Tabs = 0,
        /** Display as a row of pills */
        Pills = 1,
        /** Display as a list of pills */
        StackedPills = 2,
    }
}
export declare namespace NavList {
    /** Initializer for .with({ ... }) */
    interface Initializer extends Block.Initializer {
        /** Property initializer */
        navItems: ValueOrObservable<NavList.NavItem[]>;
        /** Property initializer */
        selectedIndex?: ValueOrObservable<number>;
        /** Property initializer */
        selectedKey?: ValueOrObservable<string>;
        /** Property initializer */
        type?: ValueOrObservable<NavList.Type>;
        /** Property initializer */
        justified?: ValueOrObservable<boolean>;
        /** Property initializer */
        BaseActivityClass?: typeof Activity;
        /** Signal initializer: method name or handler */
        NavChange?: string | ActionHandler<any, any>;
    }
}
export default NavList;
