import Block from "./Block";
import { ControlElement } from "../";
import Component from "../Component";
import { ComponentFactory, ValueOrObservable } from "../ComponentFactory";
/** Represents a row containing elements placed from left to right */
export declare class Row extends Block {
    /** Create a row block with given content, if any */
    constructor(content?: ControlElement[]);
    /** Initialize a row factory with given values */
    static with(values: Row.Initializer): ComponentFactory<Row>;
    /** Initialize a row factory with given control elements */
    static withContent(content: ComponentFactory.SpecList): ComponentFactory<Row>;
    /** Class decorator that uses given initializer specification to initialize every component instance asynchronously (after running the component constructor) */
    static initializeWith: ComponentFactory.Decorator<Row.Initializer, Row>;
    /** Class decorator that uses given initializer specification to initialize every component instance asynchronously (after running the component constructor) */
    static initializeWithContent: ComponentFactory.Decorator<ComponentFactory.SpecList, Row>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: Row.Initializer) => this;
    /** Default element spacing (CSS value, initially .5rem) */
    static DEFAULT_SPACING: string;
    /** Array of elements that go into this row (observed) */
    content: (ControlElement | null)[];
    /** Spacing between elements (CSS value, observed), defaults to DEFAULT_SPACING, i.e. 0.5rem */
    spacing: string;
    /** Vertical spacing (margin) for this row (CSS value, observed), defaults to .spacing if undefined/blank; Note: vertical spacing is not shown on fixed height rows */
    verticalSpacing: string | undefined;
    /** Returns an array of directly contained UI components (observable) */
    getChildren(): Component[];
    /** Observable value that is true if all controls are shrinkwrapped or % */
    private _allShrink;
    private _wrapper;
}
export declare namespace Row {
    /** Initializer for .with({ ... }) */
    interface Initializer extends Block.Initializer {
        /** Property initializer */
        content: ComponentFactory.SpecList;
        /** Property initializer */
        spacing?: ValueOrObservable<string>;
        /** Property initializer */
        verticalSpacing?: ValueOrObservable<string>;
    }
}
/** A row element without inner element spacing */
export declare class CloseRow extends Row {
    spacing: string;
}
export default Row;
