import ControlElement from "../ControlElement";
import { ValueOrObservable } from "../../ComponentFactory";
import TextLabelFactory from "../../TextLabelFactory";
import { ActionHandler } from "../../DOMEvents";
/** Input field control base class (abstract) */
export declare abstract class InputControl extends ControlElement {
    /** Input value (read/write) */
    value: string;
    /** Form input property name, if any (observed) */
    name: string;
    /** Label text (observed) */
    label: string;
    /** Tooltip text (title attribute; observed) */
    tooltipTitle: string;
    /** True if input is disabled and read-only (observed) */
    disabled: boolean;
    /** Signal emitted when the input value changes (DOM onChange) */
    readonly ValueChange: any;
}
export declare namespace InputControl {
    /** Initializer for .with({ ... }) */
    interface Initializer extends ControlElement.Initializer {
        /** Property initializer */
        name: string;
        /** Property initializer */
        value?: ValueOrObservable<string>;
        /** Property initializer */
        label?: ValueOrObservable<string | undefined> | TextLabelFactory;
        /** Property initializer */
        tooltipTitle?: ValueOrObservable<string | undefined> | TextLabelFactory;
        /** Property initializer */
        disabled?: ValueOrObservable<boolean>;
        /** Signal initializer: method name or handler */
        ValueChange?: string | ActionHandler<any, any>;
    }
}
export default InputControl;
