import { CustomSignalClass, Signal } from "typescene-async";
import Container from "./Components/Containers/Container";
import Activity, { ResourceActivity, ActivityTransition } from "./Activity";
import { ActivityResourcePath } from "./ActivityPath";
/** Represents an activity that corresponds to a (component on) screen */
export declare class ViewActivity extends ResourceActivity {
    /** Create a view activity with optional title and view component reference, parent reference, and resource path */
    constructor(title?: string, view?: Container, parent?: ViewActivity | typeof ViewActivity, path?: ActivityResourcePath | string);
    /** The parent view activity, if any; when set to a view activity instance, its view is automatically displayed before the current view when it is brought to the foreground */
    parentActivity: Activity | typeof Activity;
    /** The view component to be displayed, if any; the activity is automatically suspended when Closing signal is emitted (e.g. DialogContainer) */
    view: Container;
    /** Signal that is emitted before this activity's view is displayed in the foreground (i.e. NOT if displayed as parent view) */
    readonly Displaying: CustomSignalClass<ViewActivityTransition, Signal<ViewActivityTransition>>;
    /** Signal that is emitted after this activity is displayed in the foreground (i.e. NOT if displayed as parent view) */
    readonly Displayed: CustomSignalClass<ViewActivityTransition, Signal<ViewActivityTransition>>;
    /** Display the view component */
    private _displayView(resumed, t, child?, parent?);
    /** Remove the view component from the screen */
    private _removeView(t);
}
/** Represents an activity that corresponds to a component on screen, created only once and re-used if required (overrides .getInstance static method) */
export declare abstract class SingletonViewActivity extends ViewActivity {
    /** Get the instance of this activity class, constructs the instance without parameters once and returns this instance every time */
    static getInstance(): SingletonViewActivity;
    /** Create a new activity; can be used only once */
    constructor();
    private static _instance;
}
/** Represents a transition from one activity to a view activity that is to be displayed */
export interface ViewActivityTransition {
    /** The activity transition itself */
    transition: ActivityTransition;
    /** True if displaying this view for the first time (i.e. the activity has just been added, and not resumed or added again) */
    firstDisplay: boolean;
    /** True if adding this view to the history (i.e. not resuming from history) */
    forward: boolean;
    /** Number of transitions in the current chain (for checking if e.g. a dropActivity(...) call crossed multiple activities to get to this view) */
    hops: number;
}
export default ViewActivity;
